function RemoveOutlierTrialsFromData

load Subject1_v4pt3_etmData_bothLegs_replaceRMGAS.mat

DataLeg = {etmData_l,etmData_r};

RemovedTrials = 0;
nTrialsAll = 0;
for kkk = 1:2
    
    Data = DataLeg{kkk};
    
    nTrials = length(Data);
    nTrialsAll = nTrialsAll+nTrials;
    nptsLong = 141;
    nptsShort = 101;
    nMusc = 36;
    nEMG = 14;
    SampleStep = 1;
    
    Time = zeros(nptsLong,nTrials);
    JAngles = zeros(nptsLong,6,nTrials);
    JVels = zeros(nptsLong,6,nTrials);
    HipMA = zeros(nptsLong,nMusc,nTrials);
    HipAAMA = zeros(nptsLong,nMusc,nTrials);
    KneeMA = zeros(nptsLong,nMusc,nTrials);
    AnkleMA = zeros(nptsLong,nMusc,nTrials);
    SubtalarMA = zeros(nptsLong,nMusc,nTrials);
    Lmt = zeros(nptsLong,nMusc,nTrials);
    Vmt = zeros(nptsLong,nMusc,nTrials);
    IDloads = zeros(nptsLong,5,nTrials);
    EMG = zeros(nptsLong,nEMG,nTrials);
    
    for iii = 1:nTrials

        Time(:,iii) = Data(iii).Time(1:SampleStep:141);
        JAngles(:,:,iii) = Data(iii).JointAngles(1:SampleStep:141,1:6);
        JVels(:,:,iii) = Data(iii).JointVelocities(1:SampleStep:141,1:6);
        HipMA(:,:,iii) = Data(iii).HipFEMomentArms(1:SampleStep:141,:);
        HipAAMA(:,:,iii) = Data(iii).HipAAMomentArms(1:SampleStep:141,:);
        KneeMA(:,:,iii) = Data(iii).KneeMomentArms(1:SampleStep:141,:);
        AnkleMA(:,:,iii) = Data(iii).AnkleMomentArms(1:SampleStep:141,:);
        SubtalarMA(:,:,iii) = Data(iii).SubtalarMomentArms(1:SampleStep:141,:);
        Lmt(:,:,iii) = Data(iii).MuscleTendonLengths(1:SampleStep:141,:);
        Vmt(:,:,iii) = Data(iii).MuscleTendonVelocities(1:SampleStep:141,:);
        IDloads(:,:,iii) = Data(iii).InverseDynamicsLoads(1:SampleStep:141,:);
        
        tf = (Time(end,iii)-Time(1,iii))*(101/141);
        lpf = 7/tf;
        
        EMGtrial = processEMG(Data(iii).EMG, 1/1000, 40, lpf); %NOTE: the 1/1000 is a hardcoded sampling rate
        
        tf = (length(EMGtrial)-1)/1000;
        
        TimeEMGtrial = 0:(1/1000):tf;
        Time(:,iii) = linspace(0,tf,141);
        % Normalize to nptsShort time frames

        EMG(:,:,iii) = spline(TimeEMGtrial, EMGtrial', Time(:,iii))';
        
    end
    
    % Apply measured emg to similar muscles without emg
    % NOTE: This depends on the ordering of the emg columns
%     EMG = EMG(:,[6? 7 9 ? 10? 5 4 11 3 12 1 ? 13 14 ? ?]);
%     EMG = EMG(:,[ones(1,6) 2*ones(1,3) 3*ones(1,6) 4*ones(1,2) 5*ones(1,2) 6*ones(1,2) 7:9 9 10*ones(1,2) 11:12 13*ones(1,3) 14:16],:);
    EMG = EMG(:,[6*ones(1,6) 7*ones(1,3) 9*ones(1,6) 8 10*ones(1,2) 5*ones(1,2) 4 11 3*ones(1,2) 2 12 1 13*ones(1,3) 14],:);
    
    
    DataStruct.Time = Time;
    DataStruct.JAngles = JAngles;
    DataStruct.JVels = JVels;
    DataStruct.HipMA = HipMA;
    DataStruct.HipAAMA = HipAAMA;
    DataStruct.KneeMA = KneeMA;
    DataStruct.AnkleMA = AnkleMA;
    DataStruct.SubtalarMA = SubtalarMA;
    DataStruct.Lmt = Lmt;
    DataStruct.Vmt = Vmt;
    DataStruct.IDloads = IDloads;
    DataStruct.EMG = EMG;
    DataStruct.nTrials = nTrials;
    
    [DataStruct, outliers] = removeOutliers(DataStruct);
    
    fprintf(['\nRemoved ' num2str(nTrials-DataStruct.nTrials) ' trials out of ' num2str(nTrials) '.\n'])
    
    RemovedTrials = RemovedTrials+nTrials-DataStruct.nTrials;
    
    
    Data(outliers) = [];
    DataLeg{kkk} = Data;
    
end

fprintf(['\nRemoved ' num2str(RemovedTrials) ' trials out of ' num2str(nTrialsAll) '.\n'])

etmData_l = DataLeg{1};
etmData_r = DataLeg{2};

save Subject1_v4pt3_etmData_bothLegs_replacedRMGAS_outliersRemoved.mat etmData_l etmData_r
end

function emgFiltered = processEMG(emgData, dt, HPcutoff, LPcutoff)
% Function that process EMG data according the the process described by
% Lloyd and Besier (2003)
% Inputs:
%       emgData is a M x N matrix of unfiltered EMG data where M is the
%           number of time frames and N is the number of muscles
%       dt is the time step used in the EMG data
%       HPcutoff is the cutoff frequency for the high pass filter
%       LPcutoff is the cutoff frequency for the low pass filter
% Outputs:
%       emgFiltered is the filtered EMG data

SampRate = 1/mean(dt);

% High pass filter the data
degree = 4;
[z,p,k] = butter(degree, HPcutoff/SampRate*2,'high');
[sos,g] = zp2sos(z,p,k);      % Convert to SOS(second-order-sections) form
EMG_HP = filtfilt(sos,g,emgData);

% Demean
EMG_DM = EMG_HP-ones(size(EMG_HP,1),1)*mean(EMG_HP);

% Rectify
EMG_RF = abs(EMG_DM);

% Low pass filter
degree = 4;

[z,p,k] = butter(degree,LPcutoff/SampRate*2);
[sos,g] = zp2sos(z,p,k);      % Convert to SOS(second-order-sections) form
% pad data with final values
numPad = 0;
EMG_Padded = [ones(numPad,1)*EMG_RF(1,:);EMG_RF;ones(numPad,1)*EMG_RF(end,:)];
EMG_LP = filtfilt(sos,g,EMG_Padded);
emgFiltered = EMG_LP(numPad+1:end-numPad,:);

% Remove any negative EMG values that may still exist
emgFiltered(emgFiltered<0) = 0;
end

function [Data, outliers] = removeOutliers(DataStruct)

Time = DataStruct.Time;
JAngles = DataStruct.JAngles;
JVels = DataStruct.JVels;
HipMA = DataStruct.HipMA;
HipAAMA = DataStruct.HipAAMA;
KneeMA = DataStruct.KneeMA;
AnkleMA = DataStruct.AnkleMA;
SubtalarMA = DataStruct.SubtalarMA;
Lmt = DataStruct.Lmt;
Vmt = DataStruct.Vmt;
IDloads = DataStruct.IDloads;
EMG = DataStruct.EMG;
nTrials = DataStruct.nTrials;

%Remove any trials with NaN moment arms
outliers = sign(max(max(isnan(HipMA)))+max(max(isnan(HipAAMA)))+max(max(isnan(KneeMA)))...
    +max(max(isnan(AnkleMA)))+max(max(isnan(SubtalarMA))));

outliers = logical(permute(outliers,[3 1 2]));

%Remove any trials with excessively large EMG values pre-normalization
EMGmax = permute(max(EMG,[],1), [2 3 1]);
EMGmaxmean = mean(EMGmax,2);

outliers = outliers+max(EMGmax>EMGmaxmean*ones(1,nTrials)*2)';

%Remove any trials with strage ID load curves
IDloadsmean = mean(IDloads,3);
IDloadsmean = repmat(IDloadsmean, [1 1 nTrials]);

IDloadsdiff = IDloads-IDloadsmean;
IDloadsdiffstd = std(IDloadsdiff,[],3);
IDloadsdiffstd = repmat(IDloadsdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(IDloadsdiff)>5*IDloadsdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange joint angles
JAnglesmean = mean(JAngles,3);
JAnglesmean = repmat(JAnglesmean, [1 1 nTrials]);

JAnglesdiff = JAngles-JAnglesmean;
JAnglesdiffstd = std(JAnglesdiff,[],3);
JAnglesdiffstd = repmat(JAnglesdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(JAnglesdiff)>5*JAnglesdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange joint velocities
JVelsmean = mean(JVels,3);
JVelsmean = repmat(JVelsmean, [1 1 nTrials]);

JVelsdiff = JVels-JVelsmean;
JVelsdiffstd = std(JVelsdiff,[],3);
JVelsdiffstd = repmat(JVelsdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(JVelsdiff)>5*JVelsdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange hip fe moment arms
HipMAmean = mean(HipMA,3);
HipMAmean = repmat(HipMAmean, [1 1 nTrials]);

HipMAdiff = HipMA-HipMAmean;
HipMAdiffstd = std(HipMAdiff,[],3);
HipMAdiffstd = repmat(HipMAdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(HipMAdiff)>5*HipMAdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange hip aa moment arms
HipAAMAmean = mean(HipAAMA,3);
HipAAMAmean = repmat(HipAAMAmean, [1 1 nTrials]);

HipAAMAdiff = HipAAMA-HipAAMAmean;
HipAAMAdiffstd = std(HipAAMAdiff,[],3);
HipAAMAdiffstd = repmat(HipAAMAdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(HipAAMAdiff)>5*HipAAMAdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange knee fe moment arms
KneeMAmean = mean(KneeMA,3);
KneeMAmean = repmat(KneeMAmean, [1 1 nTrials]);

KneeMAdiff = KneeMA-KneeMAmean;
KneeMAdiffstd = std(KneeMAdiff,[],3);
KneeMAdiffstd = repmat(KneeMAdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(KneeMAdiff)>5*KneeMAdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange ankle moment arms
AnkleMAmean = mean(AnkleMA,3);
AnkleMAmean = repmat(AnkleMAmean, [1 1 nTrials]);

AnkleMAdiff = AnkleMA-AnkleMAmean;
AnkleMAdiffstd = std(AnkleMAdiff,[],3);
AnkleMAdiffstd = repmat(AnkleMAdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(AnkleMAdiff)>5*AnkleMAdiffstd,[],1),[],2), [3 1 2]);

%Remove trials with strange subtalar moment arms
SubtalarMAmean = mean(SubtalarMA,3);
SubtalarMAmean = repmat(SubtalarMAmean, [1 1 nTrials]);

SubtalarMAdiff = SubtalarMA-SubtalarMAmean;
SubtalarMAdiffstd = std(SubtalarMAdiff,[],3);
SubtalarMAdiffstd = repmat(SubtalarMAdiffstd, [1 1 nTrials]);
outliers = outliers+permute(max(max(abs(SubtalarMAdiff)>5*SubtalarMAdiffstd,[],1),[],2), [3 1 2]);

outliers = logical(sign(outliers));

Time(:,outliers) = [];
JAngles(:,:,outliers) = [];
JVels(:,:,outliers) = [];
HipMA(:,:,outliers) = [];
HipAAMA(:,:,outliers) = [];
KneeMA(:,:,outliers) = [];
AnkleMA(:,:,outliers) = [];
SubtalarMA(:,:,outliers) = [];
Lmt(:,:,outliers) = [];
Vmt(:,:,outliers) = [];
IDloads(:,:,outliers) = [];
EMG(:,:,outliers) = [];
nTrials = nTrials-sum(outliers);

Data.Time = Time;
Data.JAngles = JAngles;
Data.JVels = JVels;
Data.HipMA = HipMA;
Data.HipAAMA = HipAAMA;
Data.KneeMA = KneeMA;
Data.AnkleMA = AnkleMA;
Data.SubtalarMA = SubtalarMA;
Data.Lmt = Lmt;
Data.Vmt = Vmt;
Data.IDloads = IDloads;
Data.EMG = EMG;
Data.nTrials = nTrials;
end
